repeatedly
Types
Functions
pub fn call(delay_ms: Int, function: fn(Int) -> a) -> Repeater
Call a function every specified number of milliseconds, waiting the number of milliseconds before the first call.
pub fn stop(repeater: Repeater) -> Nil
Stop the repeater, preventing it from triggering again.
On Erlang if the repeater message queue is not empty then this message will handled after all other messages.
On JavaScript there is no message queue so it will stop immediately, though not interrupt the function callback if currently being executed.